<no title> — CALCEPH - Fortran 77/90/95 language 3.4.1 documentation

    integer*8 peph
    integer res, nvalue
    double precision, allocatable :: radii
    double precision svalue

    res = f90calceph_open(peph, "example1.dat")
    if (res.eq.1) then
         ! get the number of values
         nvalue = calceph_getconstantsd(peph, "BODY399_RADII", svalue)
         ! fill the array
         allocate(radii(1:nvalue))
         res = calceph_getconstantvd(peph, "BODY399_RADII", radii, nvalue)
         write(*,*) radii

      call f90calceph_close(peph)
    endif